#!/usr/bin/env perl

use CGI;
use CGI::Util;
use strict;
use warnings;
use KinoSearch::Searcher;
use KinoSearch::Analysis::PolyAnalyzer;

my $cgi = CGI->new;
#my $q = $cgi->param('q') || '';
my $q = CGI::Util::simple_escape( $cgi->param('q') ) || '';
$q =~ s/\//&#47;/g;
$q =~ s/\(/&#40;/g;
$q =~ s/\)/&#41;/g;

my $report = '';
eval {
    ### STEP 1: Specify the same Analyzer used to create the invindex
    my $analyzer = KinoSearch::Analysis::PolyAnalyzer->new(language => 'en');

    ### STEP 2: Create a Searcher object
    my $searcher = KinoSearch::Searcher->new(
        #if this breaks in the product, I'll bet it's right here...
	#invindex    => '/opt/pmx/var/www/admin/Help/kindex',
	invindex    => './kindex',
	analyzer    => $analyzer,
    );

    ### STEP 3: Feed the query to the Search Object
    my $hits = $searcher->search($q);

    ### STEP 4: Arrange for highlighted excerpts to be created
    my $highlighter = KinoSearch::Highlight::Highlighter->new(
	excerpt_field => 'content',
    );
    $hits->create_excerpts(highlighter => $highlighter);

    ### STEP 5: Process the search.
    # Nothing for us -- no paging

    ### STEP 6: Format the results however you like.
    my $total_hits = $hits->total_hits;
    while (my $hit = $hits->fetch_hit_hashref) {
	$report .= qq(
		<a target="contentwin" href="$hit->{url}">
		    <strong>$hit->{title}</strong>
		</a>
	    <br />
	    $hit->{excerpt}
	    <br /><br />
	    );
    }
};

warn "Help search: $@" if $@;

$report ||= qq(The search for <font color="#777">$q</font> returned no results.</strong>);

$q =~ s/"/&quot;/g;

print "Content-type: text/html\n\n";
print <<EOSTUFF;
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Sophos Web Security Appliance</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<link rel="stylesheet" type="text/css" href="css/code.css"></link>
	<link rel="stylesheet" type="text/css" href="css/screen.css"></link>
	<link rel="stylesheet" type="text/css" href="../so_help.css"></link>
	<script type="text/javascript" src="mm_rollover.js"></script>

	<style type="text/css">
		<!--
		body {background-color: #b4d9f3;} 
		-->
	</style>

</head>
	<body>
	<table width="299" border="0" cellpadding="0" cellspacing="0">
  <tr>
    <td width="12" height="40">&nbsp;</td>
    <td width="24"><img src="../images/ico_search.png" alt="" width="16" height="16" /></td>
    <form name="searchform" action="help_search.cgi">
      <td width="231"><input name="q" type="text" value="$q" class="inputActive" size="38" /></td>
      <td width="33"><a href="#" onmouseover="MM_swapImage('search','','../images/btn_gosearch_b.gif',1)" onmouseout="MM_swapImgRestore()">
	<img src="../images/btn_gosearch_a.gif" alt="Go" name="search" width="20" height="17" border="0" id="search" onclick="document.searchform.submit();return false;" /></a></td>
    </form>
  </tr>
  <tr>
    <td colspan="4">
	<a href="hlp_menu.html" onmouseover="MM_swapImage('Contents','','../images/mm_content_b.png',1)" onmouseout="MM_swapImgRestore()">
	<img src="../images/mm_content_a.png" alt="Contents" name="Contents" width="299" height="27" border="0" id="Contents" /></a>
	<a href="#" target="resultWin"></a>
	</td>
  </tr>
  <tr>
    <td colspan="4">
	<!-- Search query results -->
	<div name="resultsWin" id="resultsWin" style="overflow:auto; height:290px; width:298; border:1px; margin: 6px 6px 6px 10px;">
	<div id="container">
   <div id="containerTop">
    <div id="main">
  <div id="content">
$report
   	   </div>
  	  </div>
 	 </div>
	</div>
	</div>
	</td>
  </tr>

  <tr>
    <td colspan="3"></td>
  </tr>
</table>
</body>
</html>
EOSTUFF
